@@ -1,6 +1,6 @@
 # -*- cperl; cperl-indent-level: 4 -*-
-# Copyright (C) 2009-2020, Roland van Ipenburg
-package HTML::Hyphenate v1.1.7;
+# Copyright (C) 2009-2021, Roland van Ipenburg
+package HTML::Hyphenate v1.1.8;
 use Moose;
 use utf8;
 use 5.016000;
@@ -11,7 +11,7 @@ use charnames ();
 use Set::Scalar;
 use TeX::Hyphen;
 use TeX::Hyphen::Pattern 0.100;
-use Mojo::DOM;
+use HTML::Hyphenate::DOM;
 
 use Readonly;
 ## no critic qw(ProhibitCallsToUnexportedSubs)
@@ -73,7 +73,7 @@ after 'html' => sub {
         }
     }
 };
-has style => ( is => 'rw', isa => 'Str' );
+has style      => ( is => 'rw', isa => 'Str' );
 has min_length =>
   ( is => 'rw', isa => 'Int', default => $DEFAULT{'MIN_LENGTH'} );
 has min_pre  => ( is => 'rw', isa => 'Int', default => $DEFAULT{'MIN_PRE'} );
@@ -106,7 +106,7 @@ after 'classes_excluded' => sub {
 has _hyphenators   => ( is => 'rw', isa => 'HashRef', default => sub { {} } );
 has _lang          => ( is => 'rw', isa => 'Str' );
 has _doctype       => ( is => 'rw', isa => 'Str' );
-has _dom           => ( is => 'rw', isa => 'Mojo::DOM' );
+has _dom           => ( is => 'rw', isa => 'HTML::Hyphenate::DOM' );
 has _scope_is_root => ( is => 'rw', isa => 'Bool', default => sub { 0 } );
 has _classes       => ( is => 'rw', isa => 'Bool', default => sub { 0 } );
 ## use critic
@@ -186,9 +186,7 @@ sub _traverse_dom {
             {
                 $self->_configure_lang($node);
                 my $hyphened = $self->_hyphen($string);
-                if ( $hyphened ne $string ) {
-                    $node->replace($hyphened);
-                }
+                $node->replace($hyphened);
             }
             return;
         }
@@ -359,7 +357,7 @@ sub _get_nearest_ancestor_level_by_classname {
 
 sub _reset_dom {
     my ($self) = @_;
-    my $dom = Mojo::DOM->new();
+    my $dom = HTML::Hyphenate::DOM->new();
     $self->_dom($dom);
     return;
 }
@@ -370,7 +368,7 @@ __END__
 
 =encoding utf8
 
-=for stopwords Ipenburg Readonly merchantability Mojolicious
+=for stopwords Ipenburg Readonly merchantability Mojolicious Bitbucket
 
 =head1 NAME
 
@@ -378,7 +376,7 @@ HTML::Hyphenate - insert soft hyphens into HTML
 
 =head1 VERSION
 
-This document describes HTML::Hyphenate version v1.1.7.
+This document describes HTML::Hyphenate version C<v1.1.8>.
 
 =head1 SYNOPSIS
 
@@ -534,8 +532,7 @@ converted to a different notation.
 =back
 
 Please report any bugs or feature requests at
-L<RT for rt.cpan.org|
-https://rt.cpan.org/Dist/Display.html?Queue=HTML-Hyphenate>.
+L<Bitbucket|https://bitbucket.org/rolandvanipenburg/html-hyphenate/issues>.
 
 =head1 AUTHOR
 
@@ -543,7 +540,7 @@ Roland van Ipenburg, E<lt>roland@rolandvanipenburg.comE<gt>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (C) 2009-2020, Roland van Ipenburg
+Copyright (C) 2009-2021, Roland van Ipenburg
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.14.0 or,
